<?php
/**
 * WPtap Theme class
 */
defined('WPTAP_PLUGIN_NAME') or exit('Access Denied');

/**
 * All themes info.
 *
 * @return array
 */
function wptap_all_themes_info()
{
	global $wptap_themes;

	if(!empty($wptap_themes) && is_array($wptap_themes)) {
		return $wptap_themes;
	}

	$wptap_theme_root = WPTAP_PLUGIN_PATH .'themes';
	$wptap_themes_dir = @opendir($wptap_theme_root);

	if(!$wptap_themes_dir) {
		return false;
	}

	while( ($wptap_theme_dir = readdir($wptap_themes_dir)) !== false) {
		if( is_dir($wptap_theme_root .DS. $wptap_theme_dir) ) {
			if($wptap_theme_dir == '.' || $wptap_theme_dir == '..') {
				continue;
			}

			$stylish_dir = @opendir($wptap_theme_root .DS. $wptap_theme_dir);
			while( ($theme_file = readdir($stylish_dir)) !== false ) {
				if ( $theme_file == 'style.css' ) {
					$theme_files[] = $wptap_theme_dir .DS. $theme_file;
					break;
				}
			}
			@closedir($stylish_dir);
		}
	}

	if(!$wptap_themes_dir || !$theme_files) {
		return $wptap_themes;
	}

	sort($theme_files);
		
	foreach ( (array) $theme_files as $theme_file ) {
		$theme_data = get_theme_data("$wptap_theme_root/$theme_file");

		$name        = $theme_data['Name'];
		$title       = $theme_data['Title'];
		$description = wptexturize($theme_data['Description']);
		$version     = $theme_data['Version'];
		$author      = $theme_data['Author'];
		$template    = $theme_data['Template'];
		$stylesheet  = dirname($theme_file);

		$screenshot = false;
		foreach ( array('png', 'gif', 'jpg', 'jpeg') as $ext ) {
			if (file_exists("$wptap_theme_root/$stylesheet/screenshot.$ext")) {
				$screenshot = "screenshot.$ext";
				break;
			}
		}

		if ( empty($name) ) {
			$name = dirname($theme_file);
			$title = $name;
		}

		$themes[dirname($theme_file)] = array('Name' => $name, 'Title' => $title, 'Description' => $description, 'Author' => $author, 'Version' => $version, 'Screenshot' => $screenshot, 'Tags' => $theme_data['Tags'], 'URI' => $theme_data['URI']);
	}

	return $wptap_themes = $themes;
}

/**
 * get themes
 *
 * @access puglic
 * @return array themes array
 */

function wptap_get_themes()
{
	global $wptap_themes;

	$themes = array();

	foreach($wptap_themes as $k => $wptap_theme) {
		$themes[] = $k;
	}

	return $themes;
}

/**
 * WPtap current theme info
 */

function wptap_current_theme()
{
	$wptap_setting = wptap_get_settings();

	$current_theme_dir = WPTAP_THEME_PATH . $wptap_setting['theme'] .DS;

	if(!is_dir($current_theme_dir)) {
		return false;
	}
	
	return $wptap_setting['theme'];
}

/**
 * Remove theme
 *
 * @param string theme name
 * @access public
 * @return boolean
 */
function wptap_remove_theme($theme='')
{
	global $wptap_themes, $wptap_theme_oper_message;

	if( !array_key_exists($theme, $wptap_themes) ) {
		$wptap_theme_oper_message = __($theme . ' theme not exist!');
		return false;
	}

	wptap_remove_directory( WPTAP_THEME_PATH.$theme );

	if(is_dir( WPTAP_THEME_PATH.$theme )) {
		$wptap_theme_oper_message = __($theme . ' theme remove error! Please check '.WPTAP_THEME_PATH.$theme.' directory permissions.');
	} else {
		unset($wptap_themes[$theme]);
		wptap_all_themes_info();
		$wptap_theme_oper_message = __('The selected theme(s) has been removed.');
	}

	add_action('wptap_notice', 'wptap_message');
}

if(!function_exists('wptap_theme_backup')) {
	function wptap_backup_theme($themes)
	{
		global $wptap_themes, $wptap_theme_oper_message;

		$bakupthemes = array();
		$backupname = WPTAP_THEME_BACKUP_PATH.'themes-backup.zip';

		add_action('wptap_notice', 'wptap_message');

		if(empty($themes)) {
			$wptap_theme_oper_message = 'Please select themes that you want to back up.';
			return $wptap_theme_oper_message;
		}

		foreach($themes as $theme) {
			if(!isset($wptap_themes[$theme]))
				continue;

			$bakupthemes[] = str_replace('\\', '/', WPTAP_THEME_PATH . $theme);
		}

		if($bakupthemes) {
			wptap_zip_file($bakupthemes, $backupname);
			$wptap_theme_oper_message = 'Themes backup success! Backup path in: ' . $backupname;
		} else {
			$wptap_theme_oper_message = 'Themes backup Wrong! Please backup again';
			return;
		}
		ob_end_clean();
		header("Pragma: public");
		header('Expires: '.gmdate('D, d M Y H:i:s').' GMT');
		header("Cache-Control: must-revalidate, post-check=0, pre-check=0");
		header("Cache-Control: private",false);
		header('Content-type: application/zip');;
		header('Content-Disposition: attachment; filename="Backup-'.date('Y-m-d').'.zip"');
		header("Content-Transfer-Encoding: binary");
		header("Content-Length: ".filesize( $backupname ));
		set_time_limit(0);
		readfile($backupname) or die('Error');

		if(!unlink($backupname)) {
			$wptap_theme_oper_message .= 'Please remove '.$backupname.'file.';
		}
	}
}

/**
 * remove directory
 *
 * @access private
 */
function wptap_remove_directory($dir) {
	if ($handle = opendir("$dir")) {
		while (false !== ($item = readdir($handle))) {
			if ($item != "." && $item != "..") {
				if (is_dir("$dir/$item")) {
					wptap_remove_directory("$dir/$item");
				} else {
					unlink("$dir/$item");
				}
			}
		}
		closedir($handle);
		rmdir($dir);
	}
}

/**
 *
 */
function wptap_install_theme()
{
	$installSuccess = false;

	if(isset($_FILES['wptapInstallTheme']) && !empty($_FILES['wptapInstallTheme'])) {
		$theme = $_FILES['wptapInstallTheme'];
		$name = $theme['name'];
		$type = $theme['type'];
		$tmp_name = $theme['tmp_name'];
		$error = $theme['error'];

		if($error==0 && $type=='application/zip') {
			$installzip = WPTAP_THEME_PATH . $name;
			if(!move_uploaded_file($tmp_name, $installzip)) {
				return false;
			}

			if(wptap_is_install_theme($installzip)) {

				$archive = new PclZip($installzip);

				if ($archive->extract(PCLZIP_OPT_PATH, WPTAP_THEME_PATH) == 0) {
					die("Error : ".$archive->errorInfo(true));
				}

				$installSuccess = true;
				$message = __('Install succeeded.');
			} else {
				$message = __('The selected file package is not valid. Please select a valid WPtap theme package in zip format.');
			}

			if(!unlink($installzip)) {
				echo 'Please theme zip package in '.$installzip;
			}
		} else {
			$message = __('The selected file package is not valid. Please select a valid WPtap theme package in zip format.');
		}

		add_action('wptap_notice', 'wptap_message');
	}

	if(isset($message)) {
		do_action('wptap_notice', $message);
		//$form .= '<div id="message" class="updated wptapthemeopermessage">'.$message.'</div>';
	}
	
	if($installSuccess) {
		$form .= '<div style="margin-top:15px;text-align:center;"><button onclick="h();" class="button-primary">Close & Reload Page</button></div>
			<script type="text/javascript">
			function h()
			{
				parent.location.href = "admin.php?page=wptap-themes-manage";
			}
			</script>';
	} else {
		$form .= <<< EOD
<h5>Please select the WPtap theme package (in .zip format):</h5>

<div style="margin-top:10px;">
<form enctype="multipart/form-data" action="" method="post">
	<input type="file" name="wptapInstallTheme">
	<input type="submit" value="submit" class="button-primary">
</form>
</div>
EOD;
	}
	
	echo $form;
}

function wptap_is_install_theme($themezip)
{
	$is_theme = false;
	$zip = new PclZip($themezip);

	if (($list = $zip->listContent()) == 0) {
		die("Error : ".$zip->errorInfo(true));
	}

	for ($i=0; $i<sizeof ($list); $i++) {
		$file = explode('/', $list[$i]['filename']);
		$style = isset($file[1]) ? $file[1] : '';

		if(preg_match("/(.*)style\.css$/", $style)) {
			$is_theme = true;
			break;
		}
	}

	return $is_theme;
}

function wptap_upload_zip()
{
	add_action('admin_head_wptap_install_theme', 'admin_head_wptap_install_theme');
	return wp_iframe( 'wptap_install_theme');
}

wptap_all_themes_info();

add_action('media_upload_zip', 'wptap_upload_zip');
?>